from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class HandyUtilsConfig(AppConfig):
    name = 'handytools.handyutils'
    verbose_name = _('Handy Utils App')
