# Generated by Django 2.2.1 on 2019-05-13 16:54

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TextPhrase',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=255, null=True, verbose_name='Title')),
                ('phrase_type', models.CharField(db_index=True, max_length=255, verbose_name='Phrase Type')),
                ('text', models.TextField(verbose_name='Text')),
                ('language', models.CharField(default='global', max_length=6, verbose_name='Language')),
            ],
            options={
                'verbose_name': 'Text Phrase',
                'verbose_name_plural': 'Text Phrases',
                'ordering': ('phrase_type',),
                'abstract': False,
            },
        ),
    ]
