# Generated by Django 2.2.1 on 2019-05-14 07:33

import ckeditor_uploader.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='TextImagePhrase',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255, verbose_name='Title')),
                ('text', ckeditor_uploader.fields.RichTextUploadingField(verbose_name='Text')),
                ('position', models.CharField(max_length=255, verbose_name='Location')),
                ('image', filer.fields.image.FilerImageField(on_delete=django.db.models.deletion.CASCADE, to=settings.FILER_IMAGE_MODEL, verbose_name='Image')),
            ],
            options={
                'verbose_name': 'Text & Image Phrase',
                'verbose_name_plural': 'Text & Image Phrases',
                'abstract': False,
            },
        ),
    ]
