from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class TextImagePhraseConfig(AppConfig):
    name = 'handytools.textimagephrase'
    verbose_name = _('Text Image Phrase App')
